# PEQNP [![Downloads](https://pepy.tech/badge/peqnp)](https://pepy.tech/project/peqnp)

<a href="https://www.peqnp.com"><img border="0" alt="PEQNP" src="https://raw.githubusercontent.com/maxtuno/PEQNP/master/logo.png" width="640" height="400">

## Mathematical Solver

The PEQNP System its an automatic CNF encoder integrated with Python.

- [Try PEQNP on Google Colab](https://colab.research.google.com/github/maxtuno/PEQNP/blob/master/docs/PEQNP.ipynb)
- [DRILLING PROBLEM](https://colab.research.google.com/github/maxtuno/PEQNP/blob/master/docs/drilling_problem.ipynb)
- [A TRANSPORTATION PROBLEM](https://colab.research.google.com/github/maxtuno/PEQNP/blob/master/docs/transport.ipynb)
- [KNIGHT'S TOUR SLIME CLOUD (EXTERNAL)](https://colab.research.google.com/github/maxtuno/PEQNP/blob/master/docs/knight_cloud.ipynb)
- [CELL TOWER MAXIMAL COVERAGE AT MINIMAL COST](https://colab.research.google.com/github/maxtuno/PEQNP/blob/master/docs/CELL_TOWER_COVERAGE.ipynb)

## Installation
```python
pip install PEQNP
```

## SLIME 4 SAT Solver 

[Sat Competition 2020, 3rd place on Cloud Tack](https://satcompetition.github.io/2020/results.html)

<img border="0" alt="SLIME" src="https://raw.githubusercontent.com/maxtuno/PEQNP/master/medal.jpg" width="200" height="267">

<img
  src="https://cr-ss-service.azurewebsites.net/api/ScreenShot?widget=summary&username=maxtuno&badges=2&show-avatar=true&style=--header-bg-color:%23000;--border-radius:10px"/>
